Enum github_rs::github::MediaType
[−]
[src]
pub enum MediaType {
Json,
RawJson,
TextJson,
HtmlJson,
FullJson,
Diff,
Patch,
Raw,
Sha,
Html,
Base64,
}Various Media Types that can be used to access the Github API by default it just uses Json but various endpoints can return data differently based off the Media Type. Care should be used as some methods will fail given parsing to specific types.
Variants
JsonGet JSON back from the API
RawJsonGet Raw JSON back from the API
TextJsonGet Text in JSON form back from the API
HtmlJsonGet HTML in JSON form back from the API
FullJsonGet Full in JSON form back from the API
DiffGet Diffs back from the API
PatchGet Patches back from the API
RawGet Raw data back from the API
ShaGet SHA back from the API
HtmlGet HTML back from the API
Base64Get Base64 back from the API