Struct github_rs::github::Client [] [src]

pub struct Client { /* fields omitted */ }

Struct used to make calls to the Github API.

Methods

impl Client
[src]

Generate a new Client struct with the access token so that calls can be made to the API using it

Get headers of a Client

Get token of a Client

Change headers of a Client

Change AccessToken of a Client

Create a new Client with more control then the default new method